﻿using Ant.Core.WebApi.Model;
using Central.Control.WebApi.Models.Request;
using Central.Control.WebApi.Models.Response;
using Central.Control.WebApi.Service.Interface;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Http;

namespace Central.Control.WebApi.Controllers
{
    /// <summary>
    /// 订单相关接口
    /// </summary>
    [RoutePrefix("api/order")]
    public class OrderController : ApiController
    {
        private readonly IOrderService _orderService;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="orderService"></param>
        public OrderController(IOrderService orderService)
        {
            _orderService = orderService;
        }

        /// <summary>
        /// 下单
        /// </summary>
        /// <param name="req"></param>
        /// <returns></returns>
        [HttpPost]
        [Route("")]
        public ApiResult<OrderResponseDto> Order(OrderRequestDto req)
        {
            return _orderService.Order(req);
        }

        /// <summary>
        /// 获取待烧烤的商品列表
        /// </summary>
        /// <returns></returns>
        [HttpGet]
        [Route("queueorders")]
        public ApiResult<List<QueueOrderResponseDto>> GetQueueOrders()
        {
            return _orderService.GetQueueOrders();
        }

        /// <summary>
        /// 回写流程状态
        /// </summary>
        /// <param name="req"></param>
        /// <returns></returns>
        [HttpPost]
        [Route("orderprocess")]
        public ApiResult OrderProcess(OrderProcessRequestDto req)
        {
            return _orderService.OrderProcess(req);
        }

        /// <summary>
        /// 支付回写（雏形，需要根据实际需要接入支付宝或微信）
        /// </summary>
        /// <param name="req"></param>
        /// <returns></returns>
        [AllowAnonymous]
        [HttpPost]
        [Route("paywriteback")]
        public ApiResult PayWriteBack(PayWriteBackRequestDto req)
        {
            return _orderService.PayWriteBack(req);
        }

    }
}